@@ -43,18 +43,9 @@ static FRCommandClass *parent_class = NULL;
 
 
 static gboolean
-fr_command_rar_have_rar (void)
+have_rar (void)
 {
-	char *path;
-	gboolean retval;
-	
-	retval = FALSE;
-	path = g_find_program_in_path ("rar");
-	if (path)
-		retval = TRUE;
-	g_free (path);
-	
-	return retval;
+	return is_program_in_path ("rar");
 }
 
 
@@ -183,7 +174,7 @@ add_password_arg (FRCommand	*comm,
 		char *arg, *e_password;
 		
 		e_password = escape_str (password, "\"");
-		g_assert (e_password != NULL);   /* since password is non-NULL */
+		g_assert (e_password != NULL);  /* since password is non-NULL */
 		
 		arg = g_strconcat ("-p\"", e_password, "\"", NULL);
 		
@@ -206,7 +197,7 @@ fr_command_rar_list (FRCommand *comm)
 				      process_line,
 				      comm);
 
-	if (fr_command_rar_have_rar ())
+	if (have_rar ())
 		fr_process_begin_command (comm->process, "rar");
 	else
 		fr_process_begin_command (comm->process, "unrar");
@@ -302,7 +293,7 @@ fr_command_rar_extract (FRCommand  *comm,
 {
 	GList *scan;
 
-	if (fr_command_rar_have_rar ())
+	if (have_rar ())
 		fr_process_begin_command (comm->process, "rar");
 	else
 		fr_process_begin_command (comm->process, "unrar");
@@ -344,7 +335,7 @@ static void
 fr_command_rar_test (FRCommand   *comm,
 		     const char  *password)
 {
-	if (fr_command_rar_have_rar ())
+	if (have_rar ())
 		fr_process_begin_command (comm->process, "rar");
 	else
 		fr_process_begin_command (comm->process, "unrar");
@@ -450,6 +441,11 @@ fr_command_rar_new (FRProcess  *process,
 {
 	FRCommand *comm;
 
+	if ((!is_program_in_path("rar")) ||
+	    (!is_program_in_path("unrar"))) {
+		return NULL;
+	}
+
 	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_RAR, NULL));
 	fr_command_construct (comm, process, filename);
 
