@@ -48,6 +48,7 @@ GList        *window_list = NULL;
 GList        *viewer_list = NULL;
 GList        *command_list = NULL;
 gint          force_directory_creation;
+GHashTable   *programs_cache = NULL;
 
 static gchar *add_to = NULL;
 static gint   add;
@@ -55,6 +56,8 @@ static gchar *extract_to = NULL;
 static gint   extract;
 static gchar *default_url = NULL;
 
+extern void get_supported_archive_types (void);
+
 struct poptOption options[] = {
 	{ "add-to", 'a', POPT_ARG_STRING, &add_to, 0,
 	  N_("Add files to the specified archive and quit the program"),
@@ -99,7 +102,7 @@ int main (int argc, char **argv)
 	program = gnome_program_init ("file-roller", VERSION,
 				      LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_POPT_TABLE, options,
-				      GNOME_PARAM_HUMAN_READABLE_NAME, _("File Roller"),
+				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Archive Manager"),
 				      GNOME_PARAM_APP_PREFIX, FR_PREFIX,
                                       GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
                                       GNOME_PARAM_APP_DATADIR, FR_DATADIR,
@@ -134,14 +137,15 @@ int main (int argc, char **argv)
 static void 
 initialize_data ()
 {
-	char *icon_path = PIXMAPSDIR "/file-roller.png";
-
-	if (! path_is_file (icon_path))
-                g_warning ("Could not find %s", icon_path);
-	else
-		gnome_window_icon_set_default_from_file (icon_path);
+	gtk_window_set_default_icon_name ("file-roller");
 
 	eel_gconf_monitor_add ("/apps/file-roller");
+	eel_gconf_monitor_add (PREF_NAUTILUS_CLICK_POLICY);
+
+	programs_cache = g_hash_table_new_full (g_str_hash,
+						g_str_equal,
+						g_free,
+						NULL);
 }
 
 /* Free application data. */
@@ -194,6 +198,7 @@ command_done (CommandData *cdata)
 	}
 
 	g_free (cdata->command);
+	gnome_vfs_mime_application_free (cdata->app);
 	path_list_free (cdata->file_list);
 	g_free (cdata->temp_dir);
 	if (cdata->process != NULL) 
@@ -207,6 +212,8 @@ command_done (CommandData *cdata)
 static void 
 release_data ()
 {
+	g_hash_table_destroy (programs_cache);
+
 	eel_global_client_free ();
 
 	while (viewer_list != NULL) {
@@ -318,8 +325,8 @@ prepare_app (poptContext pctx)
 {
 	char *path;
 	char *default_dir;
-	char *extract_to_path;
-        char *add_to_path;
+	char *extract_to_path = NULL;
+        char *add_to_path = NULL;
 
 	/* create the config dir if necessary. */
 
@@ -335,6 +342,8 @@ prepare_app (poptContext pctx)
 	if (eel_gconf_get_boolean (PREF_MIGRATE_DIRECTORIES, TRUE))
                 migrate_to_new_directories ();
 
+	get_supported_archive_types();
+
 	if (session_is_restored ()) {
 		load_session ();
 		return;
@@ -350,17 +359,22 @@ prepare_app (poptContext pctx)
 	} 
 
 	default_dir = get_path_from_url (default_url);
-	
-	if ((extract_to != NULL) && g_path_is_absolute (extract_to))
-		extract_to_path = get_path_from_url (extract_to);
-	else {
-		char *full_path;
-		char *current_dir = g_get_current_dir ();
 
-		full_path = g_build_filename (current_dir, extract_to, NULL);
-		g_free (current_dir);
-		extract_to_path = get_path_from_url (full_path);
-		g_free (full_path);
+	if (extract_to != NULL) {
+		if (g_path_is_absolute (extract_to))
+			extract_to_path = get_path_from_url (extract_to);
+		else {
+			char *current_dir = g_get_current_dir ();
+			char *full_path;
+
+			full_path = g_build_filename (current_dir, 
+						      extract_to, 
+						      NULL);
+			extract_to_path = get_path_from_url (full_path);
+
+			g_free (current_dir);
+			g_free (full_path);
+		}
 	}
 
         add_to_path = get_path_from_url (add_to);
@@ -372,8 +386,7 @@ prepare_app (poptContext pctx)
 
 		window = window_new ();
 		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir);
-		gtk_widget_show (window->app);
+			window_set_default_dir (window, default_dir, TRUE);
 		
 		while ((filename = poptGetArg (pctx)) != NULL) {
 			char *path;
@@ -402,9 +415,8 @@ prepare_app (poptContext pctx)
 		
 		window = window_new ();
 		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir);
-		gtk_widget_show (window->app);
-		
+			window_set_default_dir (window, default_dir, TRUE);
+
 		while ((archive = poptGetArg (pctx)) != NULL) 
 			window_archive__open_extract (window, 
 						      archive, 
